@@ -207,7 +207,7 @@ The directories are searched for in the order they appear in the list.")
       (cond (cached-value (return-from mh-picon-get-image cached-value))
             ((not host-list) (return-from mh-picon-get-image nil)))
       (setq match
-            (block 'loop
+            (block loop
               ;; u@h search
               (loop for dir in mh-picon-existing-directory-list
                     do (loop for type in mh-picon-image-types
@@ -215,15 +215,15 @@ The directories are searched for in the order they appear in the list.")
                              for file1 = (format "%s/%s.%s"
                                                  dir canonical-address type)
                              when (file-exists-p file1)
-                             do (return-from 'loop file1)
+                             do (return-from loop file1)
                              ;; [path]user
                              for file2 = (format "%s/%s.%s" dir user type)
                              when (file-exists-p file2)
-                             do (return-from 'loop file2)
+                             do (return-from loop file2)
                              ;; [path]host
                              for file3 = (format "%s/%s.%s" dir host type)
                              when (file-exists-p file3)
-                             do (return-from 'loop file3)))
+                             do (return-from loop file3)))
               ;; facedb search
               ;; Search order for user@foo.net:
               ;;   [path]net/foo/user
@@ -241,11 +241,11 @@ The directories are searched for in the order they appear in the list.")
                                       do (loop for type in mh-picon-image-types
                                                for z1 = (format "%s.%s" y type)
                                                when (file-exists-p z1)
-                                               do (return-from 'loop z1)
+                                               do (return-from loop z1)
                                                for z2 = (format "%s/face.%s"
                                                                 y type)
                                                when (file-exists-p z2)
-                                               do (return-from 'loop z2)))))))
+                                               do (return-from loop z2)))))))
       (setf (gethash canonical-address mh-picon-cache)
             (mh-picon-file-contents match)))))
 
